"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDevices = getDevices;
exports.createDevices = createDevices;
exports.deviceDescription = deviceDescription;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _lodash = require("lodash");

var _lodash2 = _interopRequireDefault(_lodash);

var _adbkit = require("adbkit");

var _adbkit2 = _interopRequireDefault(_adbkit);

var _colorsSafe = require("colors/safe");

var _colorsSafe2 = _interopRequireDefault(_colorsSafe);

var _devicePrinter = require("./devicePrinter");

var _setup = require("./../setup");

function getDevices() {
  return createDevices().then(exitOnNoDevices).then(_devicePrinter.printDevices);
}

function createDevices() {
  return _setup.adb.listDevices().then(function (devices) {
    var createDevices = devices.map(createDevice);
    return Promise.all(createDevices);
  });
}

function createDevice(_ref) {
  var id = _ref.id;
  var type = _ref.type;

  if (type !== "offline") {
    return deviceDescription(id).then(function (deviceDescription) {
      return { id: id, type: type, description: deviceDescription };
    });
  } else {
    return Promise.resolve({ id: id, type: type, description: "unknown" });
  }
}

function deviceDescription(deviceId) {
  if (_setup.deviceDescriptorFile) {
    return adbShell(deviceId, "cat " + _setup.deviceDescriptorFile).then(trimAll);
  } else {
    return Promise.resolve("unknown description");
  }
}

function adbShell(deviceId, command) {
  return _setup.adb.shell(deviceId, command).then(_adbkit2["default"].util.readAll).then(function (output) {
    return output.toString();
  });
}

function trimAll(string) {
  return string.replace(/(?:\r\n|\r|\n)/g, "<br />");
}

function exitOnNoDevices(devices) {
  if (_lodash2["default"].isEmpty(devices)) {
    console.log(_colorsSafe2["default"].red("No devices found, Deploy Droid stops."));
    process.exit();
  }

  return devices;
}
//# sourceMappingURL=device.js.map